# -*- coding: utf-8 -*-
from __future__ import (
    absolute_import,
    division,
    generators,
    nested_scopes,
    print_function,
    unicode_literals,
    with_statement,
)

import datetime

from mh_operator.legacy.common import (
    DataTableBase,
    DataTablesBase,
    RowBase,
    field_decorator,
    table_property,
)


class BatchRow(RowBase):
    """Represents a row for the Batch table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def TargetBatchDataPath(self):
        # type: () -> str | None
        return self._values[1]

    @field_decorator(index=2)
    def TargetBatchFileName(self):
        # type: () -> str | None
        return self._values[2]

    @field_decorator(index=3)
    def AppSchemaVersion(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def SchemaVersion(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def DataVersion(self):
        # type: () -> int | None
        return self._values[5]

    @field_decorator(index=6)
    def BatchState(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def AnalystName(self):
        # type: () -> str | None
        return self._values[7]

    @field_decorator(index=8)
    def AnalysisTimeStamp(self):
        # type: () -> datetime.datetime | None
        return self._values[8]

    @field_decorator(index=9)
    def FeatureDetection(self):
        # type: () -> bool | None
        return self._values[9]

    @field_decorator(index=10)
    def ReferenceWindow(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def ReferenceWindowPercentOrMinutes(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def NonReferenceWindow(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def NonReferenceWindowPercentOrMinutes(self):
        # type: () -> str | None
        return self._values[13]

    @field_decorator(index=14)
    def CorrelationWindow(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def ApplyMultiplierTarget(self):
        # type: () -> bool | None
        return self._values[15]

    @field_decorator(index=16)
    def ApplyMultiplierSurrogate(self):
        # type: () -> bool | None
        return self._values[16]

    @field_decorator(index=17)
    def ApplyMultiplierISTD(self):
        # type: () -> bool | None
        return self._values[17]

    @field_decorator(index=18)
    def ApplyMultiplierMatrixSpike(self):
        # type: () -> bool | None
        return self._values[18]

    @field_decorator(index=19)
    def IgnorePeaksNotFound(self):
        # type: () -> bool | None
        return self._values[19]

    @field_decorator(index=20)
    def RelativeISTD(self):
        # type: () -> bool | None
        return self._values[20]

    @field_decorator(index=21)
    def AuditTrail(self):
        # type: () -> bool | None
        return self._values[21]

    @field_decorator(index=22)
    def RefLibraryPathFileName(self):
        # type: () -> str | None
        return self._values[22]

    @field_decorator(index=23)
    def RefLibraryPatternPathFileName(self):
        # type: () -> str | None
        return self._values[23]

    @field_decorator(index=24)
    def LibraryMethodPathFileName(self):
        # type: () -> str | None
        return self._values[24]

    @field_decorator(index=25)
    def ReferencePatternLibraryPathFileName(self):
        # type: () -> str | None
        return self._values[25]

    @field_decorator(index=26)
    def CCMaximumElapsedTimeInHours(self):
        # type: () -> float | None
        return self._values[26]

    @field_decorator(index=27)
    def BracketingType(self):
        # type: () -> str | None
        return self._values[27]

    @field_decorator(index=28)
    def StandardAddition(self):
        # type: () -> bool | None
        return self._values[28]

    @field_decorator(index=29)
    def DynamicBackgroundSubtraction(self):
        # type: () -> bool | None
        return self._values[29]

    @field_decorator(index=30)
    def DAMethodPathFileNameOrigin(self):
        # type: () -> str | None
        return self._values[30]

    @field_decorator(index=31)
    def DAMethodLastAppliedTimeStamp(self):
        # type: () -> datetime.datetime | None
        return self._values[31]

    @field_decorator(index=32)
    def CalibrationLastUpdatedTimeStamp(self):
        # type: () -> datetime.datetime | None
        return self._values[32]

    @field_decorator(index=33)
    def AnalyzeQuantVersion(self):
        # type: () -> str | None
        return self._values[33]


class BatchDataTable(DataTableBase[BatchRow]):
    """Represents the Batch table, containing BatchRow objects."""

    pass


class SampleRow(RowBase):
    """Represents a row for the Sample table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def AcqDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[2]

    @field_decorator(index=3)
    def AcqDateTimeLocal(self):
        # type: () -> Any | None
        return self._values[3]

    @field_decorator(index=4)
    def AcqMethodFileName(self):
        # type: () -> str | None
        return self._values[4]

    @field_decorator(index=5)
    def AcqMethodPathName(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def AcqOperator(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def Barcode(self):
        # type: () -> str | None
        return self._values[7]

    @field_decorator(index=8)
    def Comment(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def DataFileName(self):
        # type: () -> str | None
        return self._values[9]

    @field_decorator(index=10)
    def DataPathName(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def Dilution(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def ExpectedBarCode(self):
        # type: () -> str | None
        return self._values[12]

    @field_decorator(index=13)
    def InjectorVolume(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def InstrumentName(self):
        # type: () -> str | None
        return self._values[14]

    @field_decorator(index=15)
    def InstrumentType(self):
        # type: () -> str | None
        return self._values[15]

    @field_decorator(index=16)
    def ISTDDilution(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def MatrixSpikeDilution(self):
        # type: () -> float | None
        return self._values[17]

    @field_decorator(index=18)
    def MatrixSpikeGroup(self):
        # type: () -> str | None
        return self._values[18]

    @field_decorator(index=19)
    def MatrixType(self):
        # type: () -> str | None
        return self._values[19]

    @field_decorator(index=20)
    def PlateCode(self):
        # type: () -> str | None
        return self._values[20]

    @field_decorator(index=21)
    def PlatePosition(self):
        # type: () -> str | None
        return self._values[21]

    @field_decorator(index=22)
    def RackCode(self):
        # type: () -> str | None
        return self._values[22]

    @field_decorator(index=23)
    def RackPosition(self):
        # type: () -> str | None
        return self._values[23]

    @field_decorator(index=24)
    def SampleAmount(self):
        # type: () -> float | None
        return self._values[24]

    @field_decorator(index=25)
    def SampleInformation(self):
        # type: () -> str | None
        return self._values[25]

    @field_decorator(index=26)
    def SampleGroup(self):
        # type: () -> str | None
        return self._values[26]

    @field_decorator(index=27)
    def SampleName(self):
        # type: () -> str | None
        return self._values[27]

    @field_decorator(index=28)
    def SamplePosition(self):
        # type: () -> str | None
        return self._values[28]

    @field_decorator(index=29)
    def SamplePrepFileName(self):
        # type: () -> str | None
        return self._values[29]

    @field_decorator(index=30)
    def SamplePrepPathName(self):
        # type: () -> str | None
        return self._values[30]

    @field_decorator(index=31)
    def SampleType(self):
        # type: () -> str | None
        return self._values[31]

    @field_decorator(index=32)
    def SamplingDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[32]

    @field_decorator(index=33)
    def SamplingTime(self):
        # type: () -> float | None
        return self._values[33]

    @field_decorator(index=34)
    def SurrogateDilution(self):
        # type: () -> float | None
        return self._values[34]

    @field_decorator(index=35)
    def TotalSampleAmount(self):
        # type: () -> float | None
        return self._values[35]

    @field_decorator(index=36)
    def TrayName(self):
        # type: () -> str | None
        return self._values[36]

    @field_decorator(index=37)
    def TuneFileLastTimeStamp(self):
        # type: () -> datetime.datetime | None
        return self._values[37]

    @field_decorator(index=38)
    def TuneFileName(self):
        # type: () -> str | None
        return self._values[38]

    @field_decorator(index=39)
    def TunePathName(self):
        # type: () -> str | None
        return self._values[39]

    @field_decorator(index=40)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[40]

    @field_decorator(index=41)
    def UserDefined1(self):
        # type: () -> str | None
        return self._values[41]

    @field_decorator(index=42)
    def UserDefined2(self):
        # type: () -> str | None
        return self._values[42]

    @field_decorator(index=43)
    def UserDefined3(self):
        # type: () -> str | None
        return self._values[43]

    @field_decorator(index=44)
    def UserDefined4(self):
        # type: () -> str | None
        return self._values[44]

    @field_decorator(index=45)
    def UserDefined5(self):
        # type: () -> str | None
        return self._values[45]

    @field_decorator(index=46)
    def UserDefined6(self):
        # type: () -> str | None
        return self._values[46]

    @field_decorator(index=47)
    def UserDefined7(self):
        # type: () -> str | None
        return self._values[47]

    @field_decorator(index=48)
    def UserDefined8(self):
        # type: () -> str | None
        return self._values[48]

    @field_decorator(index=49)
    def UserDefined9(self):
        # type: () -> str | None
        return self._values[49]

    @field_decorator(index=50)
    def Vial(self):
        # type: () -> int | None
        return self._values[50]

    @field_decorator(index=51)
    def AnalysisState(self):
        # type: () -> str | None
        return self._values[51]

    @field_decorator(index=52)
    def GraphicsSampleChromatogram(self):
        # type: () -> str | None
        return self._values[52]


class SampleDataTable(DataTableBase[SampleRow]):
    """Represents the Sample table, containing SampleRow objects."""

    pass


class ComponentRow(RowBase):
    """Represents a row for the Component table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def DeconvolutionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def ComponentID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def PrimaryHitID(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def ModelIonPeakID(self):
        # type: () -> int | None
        return self._values[5]

    @field_decorator(index=6)
    def ComponentName(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def BasePeakID(self):
        # type: () -> int | None
        return self._values[7]

    @field_decorator(index=8)
    def IsManuallyIntegrated(self):
        # type: () -> bool | None
        return self._values[8]

    @field_decorator(index=9)
    def IsBackgroundSubtracted(self):
        # type: () -> bool | None
        return self._values[9]

    @field_decorator(index=10)
    def BestHit(self):
        # type: () -> bool | None
        return self._values[10]

    @field_decorator(index=11)
    def BestHitOverridden(self):
        # type: () -> bool | None
        return self._values[11]

    @field_decorator(index=12)
    def Area(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def EndX(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def Height(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def IsAccurateMass(self):
        # type: () -> bool | None
        return self._values[15]

    @field_decorator(index=16)
    def RetentionTime(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def RetentionIndex(self):
        # type: () -> float | None
        return self._values[17]

    @field_decorator(index=18)
    def SpectrumAbundances(self):
        # type: () -> str | None
        return self._values[18]

    @field_decorator(index=19)
    def SpectrumMZs(self):
        # type: () -> str | None
        return self._values[19]

    @field_decorator(index=20)
    def StartX(self):
        # type: () -> float | None
        return self._values[20]

    @field_decorator(index=21)
    def XArray(self):
        # type: () -> str | None
        return self._values[21]

    @field_decorator(index=22)
    def YArray(self):
        # type: () -> str | None
        return self._values[22]

    @field_decorator(index=23)
    def ShapeQuality(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def DeconvolutedHeight(self):
        # type: () -> float | None
        return self._values[24]

    @field_decorator(index=25)
    def AreaPercent(self):
        # type: () -> float | None
        return self._values[25]

    @field_decorator(index=26)
    def AreaPercentMax(self):
        # type: () -> float | None
        return self._values[26]

    @field_decorator(index=27)
    def Visible(self):
        # type: () -> bool | None
        return self._values[27]

    @field_decorator(index=28)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[28]

    @field_decorator(index=29)
    def UserCustomCalculation(self):
        # type: () -> float | None
        return self._values[29]

    @field_decorator(index=30)
    def GraphicsComponentSpectrum(self):
        # type: () -> str | None
        return self._values[30]

    @field_decorator(index=31)
    def TargetedDeconvolution_IdentificationMethodID(self):
        # type: () -> int | None
        return self._values[31]

    @field_decorator(index=32)
    def TargetedDeconvolution_LibrarySearchMethodID(self):
        # type: () -> int | None
        return self._values[32]

    @field_decorator(index=33)
    def TargetedDeconvolution_LibraryEntryID(self):
        # type: () -> int | None
        return self._values[33]


class ComponentDataTable(DataTableBase[ComponentRow]):
    """Represents the Component table, containing ComponentRow objects."""

    pass


class HitRow(RowBase):
    """Represents a row for the Hit table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def DeconvolutionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def ComponentID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def HitID(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def AgilentID(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def IdentificationMethodID(self):
        # type: () -> int | None
        return self._values[6]

    @field_decorator(index=7)
    def LibrarySearchMethodID(self):
        # type: () -> int | None
        return self._values[7]

    @field_decorator(index=8)
    def LibraryEntryID(self):
        # type: () -> int | None
        return self._values[8]

    @field_decorator(index=9)
    def TargetCompoundID(self):
        # type: () -> int | None
        return self._values[9]

    @field_decorator(index=10)
    def CASNumber(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def CompoundName(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def EstimatedConcentration(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def Formula(self):
        # type: () -> str | None
        return self._values[13]

    @field_decorator(index=14)
    def KEGGID(self):
        # type: () -> str | None
        return self._values[14]

    @field_decorator(index=15)
    def LibraryMatchScore(self):
        # type: () -> float | None
        return self._values[15]

    @field_decorator(index=16)
    def LibraryRetentionIndex(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def LibraryRetentionTime(self):
        # type: () -> float | None
        return self._values[17]

    @field_decorator(index=18)
    def LibraryCompoundDescription(self):
        # type: () -> str | None
        return self._values[18]

    @field_decorator(index=19)
    def MolecularWeight(self):
        # type: () -> float | None
        return self._values[19]

    @field_decorator(index=20)
    def RTMismatchPenalty(self):
        # type: () -> float | None
        return self._values[20]

    @field_decorator(index=21)
    def RetentionIndex(self):
        # type: () -> float | None
        return self._values[21]

    @field_decorator(index=22)
    def MassMatchScore(self):
        # type: () -> float | None
        return self._values[22]

    @field_decorator(index=23)
    def MassAbundanceScore(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def MassAccuracyScore(self):
        # type: () -> float | None
        return self._values[24]

    @field_decorator(index=25)
    def MassSpacingScore(self):
        # type: () -> float | None
        return self._values[25]

    @field_decorator(index=26)
    def Visible(self):
        # type: () -> bool | None
        return self._values[26]

    @field_decorator(index=27)
    def BlankSubtracted(self):
        # type: () -> bool | None
        return self._values[27]

    @field_decorator(index=28)
    def RemovedDuplicateMZs(self):
        # type: () -> str | None
        return self._values[28]

    @field_decorator(index=29)
    def ResponseFactorForEstimation(self):
        # type: () -> float | None
        return self._values[29]

    @field_decorator(index=30)
    def MonoIsotopicMass(self):
        # type: () -> float | None
        return self._values[30]

    @field_decorator(index=31)
    def NumberOfExactMasses(self):
        # type: () -> int | None
        return self._values[31]

    @field_decorator(index=32)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[32]

    @field_decorator(index=33)
    def UserCustomCalculation(self):
        # type: () -> float | None
        return self._values[33]

    @field_decorator(index=34)
    def GraphicsHitLibrarySpectrum(self):
        # type: () -> str | None
        return self._values[34]


class HitDataTable(DataTableBase[HitRow]):
    """Represents the Hit table, containing HitRow objects."""

    pass


class IonPeakRow(RowBase):
    """Represents a row for the IonPeak table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def DeconvolutionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def ComponentID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def IonPeakID(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def TargetCompoundID(self):
        # type: () -> int | None
        return self._values[5]

    @field_decorator(index=6)
    def TargetQualifierID(self):
        # type: () -> int | None
        return self._values[6]

    @field_decorator(index=7)
    def Area(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def DeconvolutedArea(self):
        # type: () -> float | None
        return self._values[8]

    @field_decorator(index=9)
    def DeconvolutedHeight(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def EndX(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def FullWidthHalfMaximum(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def Height(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def IonPolarity(self):
        # type: () -> str | None
        return self._values[13]

    @field_decorator(index=14)
    def MZ(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def PeakStatus(self):
        # type: () -> str | None
        return self._values[15]

    @field_decorator(index=16)
    def RetentionTime(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def Saturated(self):
        # type: () -> bool | None
        return self._values[17]

    @field_decorator(index=18)
    def ScanType(self):
        # type: () -> str | None
        return self._values[18]

    @field_decorator(index=19)
    def SelectedMZ(self):
        # type: () -> float | None
        return self._values[19]

    @field_decorator(index=20)
    def Sharpness(self):
        # type: () -> float | None
        return self._values[20]

    @field_decorator(index=21)
    def SignalToNoiseRatio(self):
        # type: () -> float | None
        return self._values[21]

    @field_decorator(index=22)
    def StartX(self):
        # type: () -> float | None
        return self._values[22]

    @field_decorator(index=23)
    def Symmetry(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def XArray(self):
        # type: () -> str | None
        return self._values[24]

    @field_decorator(index=25)
    def YArray(self):
        # type: () -> str | None
        return self._values[25]

    @field_decorator(index=26)
    def UserCustomCalculation(self):
        # type: () -> float | None
        return self._values[26]


class IonPeakDataTable(DataTableBase[IonPeakRow]):
    """Represents the IonPeak table, containing IonPeakRow objects."""

    pass


class DeconvolutionMethodRow(RowBase):
    """Represents a row for the DeconvolutionMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def DeconvolutionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def Algorithm(self):
        # type: () -> str | None
        return self._values[3]

    @field_decorator(index=4)
    def ChromRangeHigh(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def ChromRangeLow(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def EICPeakThreshold(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def EICSNRThreshold(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def ExcludedMZs(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def LeftMZDelta(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def ModelShapePercentile(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def MZDeltaUnits(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def RetentionTimeBinSize(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def RightMZDelta(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def UseIntegerMZValues(self):
        # type: () -> bool | None
        return self._values[14]

    @field_decorator(index=15)
    def MaxSpectrumPeaksPerChromPeak(self):
        # type: () -> int | None
        return self._values[15]

    @field_decorator(index=16)
    def SpectrumPeakThreshold(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def UseLargestPeakShape(self):
        # type: () -> bool | None
        return self._values[17]

    @field_decorator(index=18)
    def WindowSizeFactor(self):
        # type: () -> float | None
        return self._values[18]

    @field_decorator(index=19)
    def TICAnalysis(self):
        # type: () -> bool | None
        return self._values[19]

    @field_decorator(index=20)
    def ChromPeakThreshold(self):
        # type: () -> float | None
        return self._values[20]

    @field_decorator(index=21)
    def ChromSNRThreshold(self):
        # type: () -> float | None
        return self._values[21]

    @field_decorator(index=22)
    def UseAreaFilterAbsolute(self):
        # type: () -> bool | None
        return self._values[22]

    @field_decorator(index=23)
    def AreaFilterAbsolute(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def UseAreaFilterRelative(self):
        # type: () -> bool | None
        return self._values[24]

    @field_decorator(index=25)
    def AreaFilterRelative(self):
        # type: () -> float | None
        return self._values[25]

    @field_decorator(index=26)
    def UseHeightFilterAbsolute(self):
        # type: () -> bool | None
        return self._values[26]

    @field_decorator(index=27)
    def HeightFilterAbsolute(self):
        # type: () -> float | None
        return self._values[27]

    @field_decorator(index=28)
    def UseHeightFilterRelative(self):
        # type: () -> bool | None
        return self._values[28]

    @field_decorator(index=29)
    def HeightFilterRelative(self):
        # type: () -> float | None
        return self._values[29]

    @field_decorator(index=30)
    def MaxNumPeaks(self):
        # type: () -> int | None
        return self._values[30]

    @field_decorator(index=31)
    def LargestPeaksRankedBy(self):
        # type: () -> str | None
        return self._values[31]

    @field_decorator(index=32)
    def RefineComponents(self):
        # type: () -> bool | None
        return self._values[32]

    @field_decorator(index=33)
    def MaxNumStoredIonPeaks(self):
        # type: () -> int | None
        return self._values[33]

    @field_decorator(index=34)
    def Integrator(self):
        # type: () -> str | None
        return self._values[34]

    @field_decorator(index=35)
    def Screening(self):
        # type: () -> bool | None
        return self._values[35]

    @field_decorator(index=36)
    def TargetedDeconvolution(self):
        # type: () -> bool | None
        return self._values[36]

    @field_decorator(index=37)
    def MinShapeQuality(self):
        # type: () -> float | None
        return self._values[37]

    @field_decorator(index=38)
    def MinNumPeaks(self):
        # type: () -> int | None
        return self._values[38]

    @field_decorator(index=39)
    def TICAnalysisSignalType(self):
        # type: () -> str | None
        return self._values[39]


class DeconvolutionMethodDataTable(DataTableBase[DeconvolutionMethodRow]):
    """Represents the DeconvolutionMethod table, containing DeconvolutionMethodRow objects."""

    pass


class LibrarySearchMethodRow(RowBase):
    """Represents a row for the LibrarySearchMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def IdentificationMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def LibrarySearchMethodID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def LibraryFile(self):
        # type: () -> str | None
        return self._values[4]

    @field_decorator(index=5)
    def LibraryPath(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def LibraryType(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def ScreeningEnabled(self):
        # type: () -> bool | None
        return self._values[7]

    @field_decorator(index=8)
    def ScreeningType(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def NISTCompatibility(self):
        # type: () -> bool | None
        return self._values[9]

    @field_decorator(index=10)
    def PureWeightFactor(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def SearchOrder(self):
        # type: () -> int | None
        return self._values[11]

    @field_decorator(index=12)
    def RTCalibration(self):
        # type: () -> str | None
        return self._values[12]

    @field_decorator(index=13)
    def RTMatchFactorType(self):
        # type: () -> str | None
        return self._values[13]

    @field_decorator(index=14)
    def RTMaxPenalty(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def RTPenaltyType(self):
        # type: () -> str | None
        return self._values[15]

    @field_decorator(index=16)
    def RTRange(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def RTRangeNoPenalty(self):
        # type: () -> float | None
        return self._values[17]

    @field_decorator(index=18)
    def SpectrumThreshold(self):
        # type: () -> float | None
        return self._values[18]

    @field_decorator(index=19)
    def RemoveDuplicateHits(self):
        # type: () -> bool | None
        return self._values[19]

    @field_decorator(index=20)
    def AccurateMassTolerance(self):
        # type: () -> float | None
        return self._values[20]


class LibrarySearchMethodDataTable(DataTableBase[LibrarySearchMethodRow]):
    """Represents the LibrarySearchMethod table, containing LibrarySearchMethodRow objects."""

    pass


class IdentificationMethodRow(RowBase):
    """Represents a row for the IdentificationMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def IdentificationMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def MaxHitCount(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def MaxMZ(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def MinMatchScore(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def MinMZ(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def RatioPercentUncertainty(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def MultiLibrarySearchType(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def LibrarySearchType(self):
        # type: () -> str | None
        return self._values[9]

    @field_decorator(index=10)
    def PerformExactMass(self):
        # type: () -> bool | None
        return self._values[10]

    @field_decorator(index=11)
    def ExactMassAllowMultiplyChargedIons(self):
        # type: () -> bool | None
        return self._values[11]

    @field_decorator(index=12)
    def ExactMassMaxIonsPerSpectrum(self):
        # type: () -> int | None
        return self._values[12]

    @field_decorator(index=13)
    def ExactMassMinRelativeAbundance(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def ExactMassMZDelta(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def ExactMassMinMZDelta(self):
        # type: () -> float | None
        return self._values[15]

    @field_decorator(index=16)
    def ExactMassPeakSelectionWeighting(self):
        # type: () -> str | None
        return self._values[16]


class IdentificationMethodDataTable(DataTableBase[IdentificationMethodRow]):
    """Represents the IdentificationMethod table, containing IdentificationMethodRow objects."""

    pass


class TargetCompoundRow(RowBase):
    """Represents a row for the TargetCompound table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def AgilentID(self):
        # type: () -> str | None
        return self._values[3]

    @field_decorator(index=4)
    def AverageResponseFactor(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def CASNumber(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def CellAcceleratorVoltage(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def CollisionEnergy(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def CompoundApproved(self):
        # type: () -> bool | None
        return self._values[8]

    @field_decorator(index=9)
    def CompoundGroup(self):
        # type: () -> str | None
        return self._values[9]

    @field_decorator(index=10)
    def CompoundName(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def CompoundType(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def ConcentrationUnits(self):
        # type: () -> str | None
        return self._values[12]

    @field_decorator(index=13)
    def FragmentorVoltage(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def Integrator(self):
        # type: () -> str | None
        return self._values[14]

    @field_decorator(index=15)
    def InstrumentType(self):
        # type: () -> str | None
        return self._values[15]

    @field_decorator(index=16)
    def IonPolarity(self):
        # type: () -> str | None
        return self._values[16]

    @field_decorator(index=17)
    def IonSource(self):
        # type: () -> str | None
        return self._values[17]

    @field_decorator(index=18)
    def ISTDCompoundID(self):
        # type: () -> int | None
        return self._values[18]

    @field_decorator(index=19)
    def ISTDConcentration(self):
        # type: () -> float | None
        return self._values[19]

    @field_decorator(index=20)
    def ISTDFlag(self):
        # type: () -> bool | None
        return self._values[20]

    @field_decorator(index=21)
    def KEGGID(self):
        # type: () -> str | None
        return self._values[21]

    @field_decorator(index=22)
    def LeftRetentionTimeDelta(self):
        # type: () -> float | None
        return self._values[22]

    @field_decorator(index=23)
    def LibraryMatchScore(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def MatrixSpikeConcentration(self):
        # type: () -> float | None
        return self._values[24]

    @field_decorator(index=25)
    def MolecularFormula(self):
        # type: () -> str | None
        return self._values[25]

    @field_decorator(index=26)
    def Multiplier(self):
        # type: () -> float | None
        return self._values[26]

    @field_decorator(index=27)
    def MZ(self):
        # type: () -> float | None
        return self._values[27]

    @field_decorator(index=28)
    def MZAdditional(self):
        # type: () -> str | None
        return self._values[28]

    @field_decorator(index=29)
    def MZExtractionWindowUnits(self):
        # type: () -> str | None
        return self._values[29]

    @field_decorator(index=30)
    def MZExtractionWindowFilterLeft(self):
        # type: () -> float | None
        return self._values[30]

    @field_decorator(index=31)
    def MZExtractionWindowFilterRight(self):
        # type: () -> float | None
        return self._values[31]

    @field_decorator(index=32)
    def MZScanRangeHigh(self):
        # type: () -> float | None
        return self._values[32]

    @field_decorator(index=33)
    def MZScanRangeLow(self):
        # type: () -> float | None
        return self._values[33]

    @field_decorator(index=34)
    def NoiseOfRawSignal(self):
        # type: () -> float | None
        return self._values[34]

    @field_decorator(index=35)
    def PrimaryHitPeakID(self):
        # type: () -> str | None
        return self._values[35]

    @field_decorator(index=36)
    def QuantitateByHeight(self):
        # type: () -> bool | None
        return self._values[36]

    @field_decorator(index=37)
    def ReferenceMSPathName(self):
        # type: () -> str | None
        return self._values[37]

    @field_decorator(index=38)
    def RelativeISTDMultiplier(self):
        # type: () -> float | None
        return self._values[38]

    @field_decorator(index=39)
    def RetentionTime(self):
        # type: () -> float | None
        return self._values[39]

    @field_decorator(index=40)
    def RetentionTimeDeltaUnits(self):
        # type: () -> str | None
        return self._values[40]

    @field_decorator(index=41)
    def RetentionTimeWindow(self):
        # type: () -> float | None
        return self._values[41]

    @field_decorator(index=42)
    def RetentionTimeWindowUnits(self):
        # type: () -> str | None
        return self._values[42]

    @field_decorator(index=43)
    def RightRetentionTimeDelta(self):
        # type: () -> float | None
        return self._values[43]

    @field_decorator(index=44)
    def ScanType(self):
        # type: () -> str | None
        return self._values[44]

    @field_decorator(index=45)
    def SelectedMZ(self):
        # type: () -> float | None
        return self._values[45]

    @field_decorator(index=46)
    def UncertaintyRelativeOrAbsolute(self):
        # type: () -> str | None
        return self._values[46]

    @field_decorator(index=47)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[47]

    @field_decorator(index=48)
    def UserDefined1(self):
        # type: () -> str | None
        return self._values[48]

    @field_decorator(index=49)
    def UserDefined2(self):
        # type: () -> str | None
        return self._values[49]

    @field_decorator(index=50)
    def UserDefined3(self):
        # type: () -> str | None
        return self._values[50]

    @field_decorator(index=51)
    def UserDefined4(self):
        # type: () -> str | None
        return self._values[51]

    @field_decorator(index=52)
    def CompoundMath(self):
        # type: () -> str | None
        return self._values[52]

    @field_decorator(index=53)
    def UserAnnotation(self):
        # type: () -> str | None
        return self._values[53]

    @field_decorator(index=54)
    def UserCustomCalculation(self):
        # type: () -> float | None
        return self._values[54]

    @field_decorator(index=55)
    def RetentionIndex(self):
        # type: () -> float | None
        return self._values[55]

    @field_decorator(index=56)
    def ID(self):
        # type: () -> int | None
        return self._values[56]


class TargetCompoundDataTable(DataTableBase[TargetCompoundRow]):
    """Represents the TargetCompound table, containing TargetCompoundRow objects."""

    pass


class PeakRow(RowBase):
    """Represents a row for the Peak table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def PeakID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def Area(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def CalculatedConcentration(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def CoelutionScore(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def FinalConcentration(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def FullWidthHalfMaximum(self):
        # type: () -> float | None
        return self._values[8]

    @field_decorator(index=9)
    def Height(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def IntegrationMetricQualityFlags(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def IntegrationStartTime(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def IntegrationEndTime(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def Noise(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def ManuallyIntegrated(self):
        # type: () -> bool | None
        return self._values[14]

    @field_decorator(index=15)
    def MassAccuracy(self):
        # type: () -> float | None
        return self._values[15]

    @field_decorator(index=16)
    def MassMatchScore(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def MatrixSpikePercentRecovery(self):
        # type: () -> float | None
        return self._values[17]

    @field_decorator(index=18)
    def MZ(self):
        # type: () -> float | None
        return self._values[18]

    @field_decorator(index=19)
    def Plates(self):
        # type: () -> int | None
        return self._values[19]

    @field_decorator(index=20)
    def QValueComputed(self):
        # type: () -> int | None
        return self._values[20]

    @field_decorator(index=21)
    def RetentionIndex(self):
        # type: () -> float | None
        return self._values[21]

    @field_decorator(index=22)
    def RetentionTime(self):
        # type: () -> float | None
        return self._values[22]

    @field_decorator(index=23)
    def RetentionTimeDifference(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def ResolutionFront(self):
        # type: () -> float | None
        return self._values[24]

    @field_decorator(index=25)
    def ResolutionRear(self):
        # type: () -> float | None
        return self._values[25]

    @field_decorator(index=26)
    def SaturationRecoveryRatio(self):
        # type: () -> float | None
        return self._values[26]

    @field_decorator(index=27)
    def SignalToNoiseRatio(self):
        # type: () -> float | None
        return self._values[27]

    @field_decorator(index=28)
    def SurrogatePercentRecovery(self):
        # type: () -> float | None
        return self._values[28]

    @field_decorator(index=29)
    def Symmetry(self):
        # type: () -> float | None
        return self._values[29]

    @field_decorator(index=30)
    def TargetResponse(self):
        # type: () -> float | None
        return self._values[30]

    @field_decorator(index=31)
    def UserCustomCalculation(self):
        # type: () -> float | None
        return self._values[31]

    @field_decorator(index=32)
    def UserCustomCalculation1(self):
        # type: () -> float | None
        return self._values[32]

    @field_decorator(index=33)
    def UserCustomCalculation2(self):
        # type: () -> float | None
        return self._values[33]

    @field_decorator(index=34)
    def UserCustomCalculation3(self):
        # type: () -> float | None
        return self._values[34]

    @field_decorator(index=35)
    def UserCustomCalculation4(self):
        # type: () -> float | None
        return self._values[35]

    @field_decorator(index=36)
    def Width(self):
        # type: () -> float | None
        return self._values[36]

    @field_decorator(index=37)
    def ReferenceLibraryMatchScore(self):
        # type: () -> float | None
        return self._values[37]

    @field_decorator(index=38)
    def Purity(self):
        # type: () -> float | None
        return self._values[38]


class PeakDataTable(DataTableBase[PeakRow]):
    """Represents the Peak table, containing PeakRow objects."""

    pass


class TargetQualifierRow(RowBase):
    """Represents a row for the TargetQualifier table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def QualifierID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def CollisionEnergy(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def FragmentorVoltage(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def MZ(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def MZExtractionWindowUnits(self):
        # type: () -> str | None
        return self._values[7]

    @field_decorator(index=8)
    def MZExtractionWindowFilterLeft(self):
        # type: () -> float | None
        return self._values[8]

    @field_decorator(index=9)
    def MZExtractionWindowFilterRight(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def RelativeResponse(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def SelectedMZ(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def Uncertainty(self):
        # type: () -> float | None
        return self._values[12]


class TargetQualifierDataTable(DataTableBase[TargetQualifierRow]):
    """Represents the TargetQualifier table, containing TargetQualifierRow objects."""

    pass


class PeakQualifierRow(RowBase):
    """Represents a row for the PeakQualifier table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def QualifierID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def PeakID(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def Area(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def FullWidthHalfMaximum(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def Height(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def Noise(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def ManuallyIntegrated(self):
        # type: () -> bool | None
        return self._values[9]

    @field_decorator(index=10)
    def QualifierResponseRatio(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def RetentionTime(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def SignalToNoiseRatio(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def Symmetry(self):
        # type: () -> float | None
        return self._values[13]


class PeakQualifierDataTable(DataTableBase[PeakQualifierRow]):
    """Represents the PeakQualifier table, containing PeakQualifierRow objects."""

    pass


class AnalysisRow(RowBase):
    """Represents a row for the Analysis table."""

    @field_decorator(index=0)
    def AnalysisID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SchemaVersion(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def AnalystName(self):
        # type: () -> str | None
        return self._values[2]

    @field_decorator(index=3)
    def AnalysisTime(self):
        # type: () -> datetime.datetime | None
        return self._values[3]

    @field_decorator(index=4)
    def DataVersion(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def ReportTime(self):
        # type: () -> datetime.datetime | None
        return self._values[5]

    @field_decorator(index=6)
    def StoreResultsPerSample(self):
        # type: () -> bool | None
        return self._values[6]

    @field_decorator(index=7)
    def AppVersion(self):
        # type: () -> str | None
        return self._values[7]

    @field_decorator(index=8)
    def BatchPath(self):
        # type: () -> str | None
        return self._values[8]

    @field_decorator(index=9)
    def AnalysisFileName(self):
        # type: () -> str | None
        return self._values[9]


class AnalysisDataTable(DataTableBase[AnalysisRow]):
    """Represents the Analysis table, containing AnalysisRow objects."""

    pass


class TargetMatchMethodRow(RowBase):
    """Represents a row for the TargetMatchMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def TargetMatchMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def TargetFinalConcentrationRequired(self):
        # type: () -> bool | None
        return self._values[3]

    @field_decorator(index=4)
    def TargetResponseRequired(self):
        # type: () -> bool | None
        return self._values[4]

    @field_decorator(index=5)
    def TargetQualifierIonRatiosWithinRangeRequired(self):
        # type: () -> bool | None
        return self._values[5]

    @field_decorator(index=6)
    def TargetQualifierIonRequired(self):
        # type: () -> bool | None
        return self._values[6]

    @field_decorator(index=7)
    def HitContainsQuantifierIon(self):
        # type: () -> bool | None
        return self._values[7]

    @field_decorator(index=8)
    def HitContainsQualifierIons(self):
        # type: () -> bool | None
        return self._values[8]

    @field_decorator(index=9)
    def HitQualifierRatioWithinRange(self):
        # type: () -> bool | None
        return self._values[9]

    @field_decorator(index=10)
    def HitWithinTargetRTWindow(self):
        # type: () -> bool | None
        return self._values[10]

    @field_decorator(index=11)
    def ManualResponseFactor(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def MatchCompoundName(self):
        # type: () -> bool | None
        return self._values[12]

    @field_decorator(index=13)
    def MatchCASNumber(self):
        # type: () -> bool | None
        return self._values[13]

    @field_decorator(index=14)
    def HitConcentrationEstimation(self):
        # type: () -> str | None
        return self._values[14]


class TargetMatchMethodDataTable(DataTableBase[TargetMatchMethodRow]):
    """Represents the TargetMatchMethod table, containing TargetMatchMethodRow objects."""

    pass


class AuxiliaryMethodRow(RowBase):
    """Represents a row for the AuxiliaryMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def MZExtractIons(self):
        # type: () -> str | None
        return self._values[2]

    @field_decorator(index=3)
    def MZExtractionWindowFilterLeft(self):
        # type: () -> float | None
        return self._values[3]

    @field_decorator(index=4)
    def MZExtractionWindowFilterRight(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def MZExtractionWindowUnits(self):
        # type: () -> str | None
        return self._values[5]


class AuxiliaryMethodDataTable(DataTableBase[AuxiliaryMethodRow]):
    """Represents the AuxiliaryMethod table, containing AuxiliaryMethodRow objects."""

    pass


class BlankSubtractionMethodRow(RowBase):
    """Represents a row for the BlankSubtractionMethod table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def BlankSubtractionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def PerformBlankSubtraction(self):
        # type: () -> bool | None
        return self._values[3]

    @field_decorator(index=4)
    def PeakThresholdType(self):
        # type: () -> str | None
        return self._values[4]

    @field_decorator(index=5)
    def PeakThreshold(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def RTWindowType(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def RTWindow(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def RTWindowFWHM(self):
        # type: () -> float | None
        return self._values[8]


class BlankSubtractionMethodDataTable(DataTableBase[BlankSubtractionMethodRow]):
    """Represents the BlankSubtractionMethod table, containing BlankSubtractionMethodRow objects."""

    pass


class ExactMassRow(RowBase):
    """Represents a row for the ExactMass table."""

    @field_decorator(index=0)
    def BatchID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def SampleID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def DeconvolutionMethodID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def ComponentID(self):
        # type: () -> int | None
        return self._values[3]

    @field_decorator(index=4)
    def HitID(self):
        # type: () -> int | None
        return self._values[4]

    @field_decorator(index=5)
    def ExactMassID(self):
        # type: () -> int | None
        return self._values[5]

    @field_decorator(index=6)
    def MassSource(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def MassExact(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def MassDeltaPpm(self):
        # type: () -> float | None
        return self._values[8]

    @field_decorator(index=9)
    def MassDeltaMda(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def FragmentFormula(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def Abundance(self):
        # type: () -> float | None
        return self._values[11]

    @field_decorator(index=12)
    def RelativeAbundance(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def Charge(self):
        # type: () -> int | None
        return self._values[13]

    @field_decorator(index=14)
    def IsUnique(self):
        # type: () -> bool | None
        return self._values[14]


class ExactMassDataTable(DataTableBase[ExactMassRow]):
    """Represents the ExactMass table, containing ExactMassRow objects."""

    pass


class DataTables(DataTablesBase):
    @table_property(BatchDataTable)
    def Batch(self):
        pass

    @table_property(SampleDataTable)
    def Sample(self):
        pass

    @table_property(ComponentDataTable)
    def Component(self):
        pass

    @table_property(HitDataTable)
    def Hit(self):
        pass

    @table_property(IonPeakDataTable)
    def IonPeak(self):
        pass

    @table_property(DeconvolutionMethodDataTable)
    def DeconvolutionMethod(self):
        pass

    @table_property(LibrarySearchMethodDataTable)
    def LibrarySearchMethod(self):
        pass

    @table_property(IdentificationMethodDataTable)
    def IdentificationMethod(self):
        pass

    @table_property(TargetCompoundDataTable)
    def TargetCompound(self):
        pass

    @table_property(PeakDataTable)
    def Peak(self):
        pass

    @table_property(TargetQualifierDataTable)
    def TargetQualifier(self):
        pass

    @table_property(PeakQualifierDataTable)
    def PeakQualifier(self):
        pass

    @table_property(AnalysisDataTable)
    def Analysis(self):
        pass

    @table_property(TargetMatchMethodDataTable)
    def TargetMatchMethod(self):
        pass

    @table_property(AuxiliaryMethodDataTable)
    def AuxiliaryMethod(self):
        pass

    @table_property(BlankSubtractionMethodDataTable)
    def BlankSubtractionMethod(self):
        pass

    @table_property(ExactMassDataTable)
    def ExactMass(self):
        pass

    def ComponentsWithBestPrimaryHit(self, batch_id=0, sample_id=None):
        # type: (int, int) -> dict
        component_table = self.Component
        hit_table = self.Hit

        component_table_keys = [
            "BatchID",
            "SampleID",
            "DeconvolutionMethodID",
            "ComponentID",
        ]
        hit_table_keys = component_table_keys + ["HitID"]
        hit_table_index = {
            k: r for r, k in enumerate(zip(*[hit_table[c] for c in hit_table_keys]))
        }

        component_rows, hit_rows = zip(
            *[
                (r, hit_table_index[(bid, sid, did, cid, hid)])
                # each row in component table
                for r, (bid, sid, did, cid, hid, ok) in enumerate(
                    zip(
                        *[
                            component_table[c]
                            for c in component_table_keys + ["PrimaryHitID", "BestHit"]
                        ]
                    )
                )
                # only selected batch/sample and best primary hit
                if ok and bid == batch_id and (sample_id is None or sid == sample_id)
            ]
        )

        components_with_best_primary_hit = {
            k: [v[r] for r in component_rows] for k, v in component_table.items()
        }
        components_with_best_primary_hit.update(
            **{
                k: [v[r] for r in hit_rows]
                for k, v in hit_table.items()
                if k not in hit_table_keys
            }
        )
        return components_with_best_primary_hit

    def to_json(self, processed=False):
        # type: (bool) -> str
        if processed:
            self.tables["ComponentsWithBestPrimaryHit"] = (
                self.ComponentsWithBestPrimaryHit()
            )
        else:
            self.tables.pop("ComponentsWithBestPrimaryHit", {})
        return super(DataTables, self).to_json()



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    BracketingTypeEnum,
    CalibPeakRoleEnum,
    CorrectionFactorType,
    DoubleUnitType,
    IContainer,
    IDaParam,
    IIdentifiedPeakAggregation,
    IIdentParamBaseType,
    IInjectionCompoundType,
    IInjectionContainer,
    IInjectionMeasDataType,
    IInjectionResultType,
    IInjectionSignalResultType,
    IMSSamplePurityResultType,
    IMSSamplePuritySetupType,
    InjectorPositionEnum,
    INonIdentParamBaseType,
    IPeakType,
    ISampleContainer,
    ISampleContextContainer,
    ISampleMeasDataContextType,
    ISampleMeasDataType,
    ISamplePurityContainer,
    ISampleSetupContextType,
    ISampleSetupType,
    ISignalContainer,
    ISignalType,
    LimsIDType,
    MethodRefType,
    ResponseFactorUpdateEnum,
    RetentionTimeUpdateEnum,
    RunTypeAndReplicationType,
    SampleTypeEnum,
    StandardCompoundAmountType,
)

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects

class AcamlExternalReferenceId:  # Class
    def __init__(self, docId: System.Guid, path: str, traceId: str) -> None: ...

    DocId: System.Guid  # readonly
    Path: str  # readonly
    TraceId: str  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class AcamlInjectionId:  # Class
    def __init__(self, acamlDocId: System.Guid, injectionId: System.Guid) -> None: ...

    AcamlDocId: System.Guid  # readonly
    InjectionId: System.Guid  # readonly

    def GetHashCode(self) -> int: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self,
        other: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.AcamlInjectionId,
    ) -> bool: ...

class AcamlInjectionSpectrumId:  # Class
    def __init__(
        self, acamlDocId: System.Guid, injectionId: System.Guid, spectrumName: str
    ) -> None: ...

    AcamlDocId: System.Guid  # readonly
    InjectionId: System.Guid  # readonly
    SpectrumName: str  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class AcamlSignalId:  # Class
    def __init__(self, docId: System.Guid, signal: ISignalType) -> None: ...

    DocId: System.Guid  # readonly
    SignalId: System.Guid  # readonly
    SignalName: str  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class DaParam(
    Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.NonIdentParamBaseType,
    INonIdentParamBaseType,
    IDaParam,
):  # Class
    def __init__(self) -> None: ...

    CalibrationLevel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    CalibrationStandards: System.Collections.Generic.List[StandardCompoundAmountType]
    DilutionFactors: System.Collections.Generic.List[CorrectionFactorType]
    InternalStandards: System.Collections.Generic.List[StandardCompoundAmountType]
    Multipliers: System.Collections.Generic.List[CorrectionFactorType]
    OrderNo: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    ResponseFactorUpdate: ResponseFactorUpdateEnum
    ResponseFactorUpdateSpecified: bool
    ResponseFactorUpdateWeight: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    )
    RetentionTimeUpdate: RetentionTimeUpdateEnum
    RetentionTimeUpdateSpecified: bool
    RetentionTimeUpdateWeight: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    RunTypes: System.Collections.Generic.List[RunTypeAndReplicationType]
    SampleAmount: DoubleUnitType

class IInjectionMetaData(object):  # Interface
    AcqMethodName: str
    Barcode: str
    BracketingType: BracketingTypeEnum
    CalibrationLevel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    CalibrationStandards: System.Collections.Generic.List[str]
    DaMethodName: str
    DilutionFactors: str
    ExpectedBarcode: str
    InjectionAcqDateTime: System.DateTime
    InjectionId: System.Guid
    InjectorPosition: InjectorPositionEnum
    InternalStandardAmounts: System.Collections.Generic.List[str]
    LastModifiedDateTime: System.DateTime
    LegacyCalibrationStandards: System.Collections.Generic.List[
        StandardCompoundAmountType
    ]
    LegacyDilutionFactors: System.Collections.Generic.List[CorrectionFactorType]
    LegacyInternalStandardAmounts: System.Collections.Generic.List[
        StandardCompoundAmountType
    ]
    LegacyMultipliers: System.Collections.Generic.List[CorrectionFactorType]
    LimsIds: System.Collections.Generic.List[LimsIDType]
    Multipliers: str
    RawDataFileName: str
    ReplicateNumber: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    RunTypes: System.Collections.Generic.List[RunTypeAndReplicationType]
    SampleAmount: DoubleUnitType
    SampleDescription: str
    SampleInjectionsCount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    SampleName: str
    SampleOrderNumber: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    SampleSetupId: System.Guid
    SampleType: SampleTypeEnum
    SequenceName: str
    VialNumber: str

class IdVer:  # Struct
    def __init__(self, id: System.Guid, version: int) -> None: ...

    Id: System.Guid  # readonly
    Version: int  # readonly

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class IdentParamBaseType(IIdentParamBaseType):  # Class
    Description: str
    Name: str
    ProjectID: str

class IdentifiedPeakAggregation(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
    IIdentifiedPeakAggregation,
):  # Class
    def __init__(
        self,
        peak: IPeakType,
        calibRole: CalibPeakRoleEnum,
        calibrationCurve: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
        injectionCompound: IInjectionCompoundType,
        docId: System.Guid,
    ) -> None: ...

    CalibRole: CalibPeakRoleEnum  # readonly
    CalibrationCurve: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType
    )  # readonly
    DocId: System.Guid  # readonly
    Peak: IPeakType  # readonly
    RelatedInjectionCompound: IInjectionCompoundType  # readonly

class InjectionContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    IInjectionContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, injectionMeasData: IInjectionMeasDataType, docId: System.Guid
    ) -> None: ...
    @overload
    def __init__(self, injectionMeasData: IInjectionMeasDataType) -> None: ...

    DocId: System.Guid  # readonly
    InjectionMeasData: IInjectionMeasDataType  # readonly
    InjectionResult: IInjectionResultType

class InjectionMetaData(
    Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.CustomObjects.IInjectionMetaData
):  # Class
    @overload
    def __init__(
        self, injectionSetupId: System.Guid, sampleSetupId: System.Guid
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    AcqMethodName: str
    Barcode: str
    BracketingType: BracketingTypeEnum
    CalibrationLevel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    CalibrationStandards: System.Collections.Generic.List[str]
    DaMethodName: str
    DilutionFactors: str
    ExpectedBarcode: str
    InjectionAcqDateTime: System.DateTime
    InjectionId: System.Guid
    InjectorPosition: InjectorPositionEnum
    InternalStandardAmounts: System.Collections.Generic.List[str]
    LastModifiedDateTime: System.DateTime
    LegacyBracketingType: str
    LegacyCalibrationStandards: System.Collections.Generic.List[
        StandardCompoundAmountType
    ]
    LegacyDilutionFactors: System.Collections.Generic.List[CorrectionFactorType]
    LegacyInternalStandardAmounts: System.Collections.Generic.List[
        StandardCompoundAmountType
    ]
    LegacyMultipliers: System.Collections.Generic.List[CorrectionFactorType]
    LimsIds: System.Collections.Generic.List[LimsIDType]
    Multipliers: str
    RawDataFileName: str
    ReplicateNumber: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    RunTypes: System.Collections.Generic.List[RunTypeAndReplicationType]
    SampleAmount: DoubleUnitType
    SampleDescription: str
    SampleInjectionsCount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    SampleName: str
    SampleOrderNumber: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    SampleSetupId: System.Guid
    SampleType: SampleTypeEnum
    SequenceName: str
    VialNumber: str

    @staticmethod
    def CreateValueString(valueList: System.Collections.Generic.List[float]) -> str: ...
    @staticmethod
    def CreateAmountString(
        standardCompoundAmountType: StandardCompoundAmountType,
    ) -> str: ...
    @staticmethod
    def CreateStandardCompoundAmountType(
        amountString: str,
    ) -> StandardCompoundAmountType: ...
    @staticmethod
    def CreateValueList(valueString: str) -> Iterable[float]: ...

class NonIdentParamBaseType(INonIdentParamBaseType):  # Class
    def __init__(self) -> None: ...

    Method_ID: MethodRefType

class SampleContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    ISampleContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    @overload
    def __init__(self, sampleSetup: ISampleSetupType, docId: System.Guid) -> None: ...
    @overload
    def __init__(self, sampleSetup: ISampleSetupType) -> None: ...

    DocId: System.Guid  # readonly
    SampleMeasData: ISampleMeasDataType
    SampleSetup: ISampleSetupType  # readonly

class SampleContextContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    ISampleContextContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    @overload
    def __init__(
        self, sampleSetupContext: ISampleSetupContextType, docId: System.Guid
    ) -> None: ...
    @overload
    def __init__(self, sampleSetupContext: ISampleSetupContextType) -> None: ...

    DocId: System.Guid  # readonly
    SampleMeasDataContext: ISampleMeasDataContextType
    SampleSetupContext: ISampleSetupContextType  # readonly

class SamplePurityContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    ISamplePurityContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, samplePuritySetup: IMSSamplePuritySetupType, docId: System.Guid
    ) -> None: ...
    @overload
    def __init__(self, samplePuritySetup: IMSSamplePuritySetupType) -> None: ...

    DocId: System.Guid  # readonly
    SamplePurityResult: IMSSamplePurityResultType  # readonly
    SamplePuritySetup: IMSSamplePuritySetupType  # readonly

    def AddSamplePurityResult(
        self, samplePurityResult: IMSSamplePurityResultType
    ) -> None: ...

class SignalContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    IContainer,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
    ISignalContainer,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, signalMeasData: ISignalType, docId: System.Guid) -> None: ...
    @overload
    def __init__(self, signalMeasData: ISignalType) -> None: ...

    DocId: System.Guid
    SignalMeasData: ISignalType  # readonly
    SignalRawData: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    SignalResult: IInjectionSignalResultType
    SpectrumRawData: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ApplicationServices import IApplicationServiceBase
from .ApplicationServices.Quant import IQuantitativeAnalysis
from .UIModel import IMainWindow

# Stubs for namespace: Agilent.MassHunter.Quantitative.QuantAppServices

class Client(
    IQuantitativeAnalysis, IApplicationServiceBase, System.IDisposable
):  # Class
    def __init__(self) -> None: ...

    CommunicationState: System.ServiceModel.CommunicationState  # readonly

    def CloseApplication(self) -> None: ...
    def Reconnect(self) -> None: ...
    def Connect(self) -> None: ...
    def ShowWindow(self) -> None: ...
    def Dispose(self) -> None: ...
    def RunScript(self, scriptFile: str) -> None: ...
    def ConnectWithCallback(self, callback: Any) -> None: ...

class IService(
    IQuantitativeAnalysis, IApplicationServiceBase, System.IDisposable
):  # Interface
    ...

class Service(
    System.IDisposable,
    IQuantitativeAnalysis,
    IApplicationServiceBase,
    Agilent.MassHunter.Quantitative.QuantAppServices.IService,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
        mainWindow: IMainWindow,
    ) -> None: ...

    CommunicationState: System.ServiceModel.CommunicationState  # readonly

    def CloseApplication(self) -> None: ...
    def Reconnect(self) -> None: ...
    def Open(self, key: str) -> None: ...
    def Connect(self) -> None: ...
    def ShowWindow(self) -> None: ...
    def Dispose(self) -> None: ...
    def RunScript(self, scriptFile: str) -> None: ...
    def ConnectWithCallback(self, callback: Any) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable

class ComparisonItem:  # Class
    def __init__(self) -> None: ...

    Background: System.Windows.Media.Brush  # readonly
    ComponentHit1: (
        Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.ComponentHit
    )
    ComponentHit2: (
        Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.ComponentHit
    )
    RT: float  # readonly

class ComponentComparisonControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ComponentComparisonWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(
        self,
        mainWindow: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
    ) -> None: ...
    def Configure(self) -> None: ...
    def Export(self) -> None: ...
    def Refresh(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def GetInstance(
        mainWindow: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
    ) -> (
        Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.ComponentComparisonWindow
    ): ...

class ComponentHit:  # Class
    def __init__(self) -> None: ...

    Area: Optional[float]
    BatchID: int
    ComponentID: int
    CompoundName: str
    DataFile: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataFile.DataFileBase
    )
    DeconvolutionMethodID: int
    HitID: Optional[int]
    IdentificationMethodID: Optional[int]
    LibraryEntryID: Optional[int]
    LibrarySearchMethodID: Optional[int]
    RetentionTime: float
    SampleID: int

class ConfigureModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self, model: Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.Model
    ) -> None: ...

    RTBinSize: float

class ConfigureWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        window: Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.ComponentComparisonWindow,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...

class Model(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...

    CommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext
    )  # readonly
    FileName1: str
    FileName2: str
    Items: List[
        Agilent.MassHunter.UnknownsAnalysis.ComponentComparisonTable.ComparisonItem
    ]
    RTBinSize: float
    SampleName1: str
    SampleName2: str

    def Process(self) -> None: ...
    def Clean(self) -> None: ...

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...

class ToolIds:  # Class
    ...

class ToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, uiState: Any
    ) -> None: ...
    def GetToolCaption(self, id: str) -> str: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse

class CommandLineAlias:  # Class
    def __init__(
        self,
        aliasAttr: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitchAliasAttribute,
        cmdLineSwitch: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitch,
    ) -> None: ...

    Attribute: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitchAliasAttribute
    )  # readonly
    Supplied: bool
    SwitchObject: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitch
    )  # readonly

    def AddValue(self, value_: str) -> None: ...

class CommandLineException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class CommandLineParameterType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AllowMultiple: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineParameterType
    ) = ...  # static # readonly
    HasParameter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineParameterType
    ) = ...  # static # readonly
    Optional: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineParameterType
    ) = ...  # static # readonly
    ParameterIsOptional: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineParameterType
    ) = ...  # static # readonly

class CommandLineParser:  # Class
    def __init__(self) -> None: ...
    def DisplayOptionDescriptions(
        self,
        type: System.Type,
        resourceManager: System.Resources.ResourceManager,
        writer: System.IO.TextWriter,
        width: int,
    ) -> None: ...
    def Parse(self, parameters: List[str], objCmdLine: Any) -> None: ...

class CommandLineSwitch:  # Class
    def __init__(
        self,
        switchAttribute: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitchAttribute,
        memberInfo: System.Reflection.MemberInfo,
    ) -> None: ...

    Attribute: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineSwitchAttribute
    )  # readonly
    HasValues: bool  # readonly
    Supplied: bool
    ValueCount: int  # readonly

    def AddValue(self, value_: str) -> None: ...
    def Notify(self, objCmdLine: Any) -> None: ...

class CommandLineSwitchAliasAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, alias: str) -> None: ...

    Alias: str  # readonly

class CommandLineSwitchAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, key: str) -> None: ...

    AllowsParameter: bool  # readonly
    Description: str
    Hidden: bool
    Key: str  # readonly
    ParameterName: str
    ParameterType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLineParse.CommandLineParameterType
    )



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Configuration, Properties, ViewModel
from .ViewModel import FolderTreeViewModel

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper

class ControlBox:  # Class
    HasHelpButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMaximizeButtonProperty: System.Windows.DependencyProperty  # static # readonly
    HasMinimizeButtonProperty: System.Windows.DependencyProperty  # static # readonly

    @staticmethod
    def SetHasMaximizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasHelpButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def SetHasMinimizeButton(element: System.Windows.Window, value_: bool) -> None: ...
    @staticmethod
    def GetHasHelpButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMaximizeButton(element: System.Windows.Window) -> bool: ...
    @staticmethod
    def GetHasMinimizeButton(element: System.Windows.Window) -> bool: ...

class DomainDialog(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    Domain: str  # readonly

    def InitializeComponent(self) -> None: ...

class FileDialog(
    System.Windows.Window,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    System.Windows.Markup.IStyleConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    AllowFileRevisions: bool
    DefaultExtension: str
    DefaultFileName: str
    FileMustExists: bool
    FileMustNotExist: bool
    Filters: str
    InitialFolder: str
    Multiselect: bool
    OkButtonText: str
    OpenMode: bool  # readonly
    OverwritePrompt: bool
    PathName: str
    PathNames: List[str]
    Readonly: bool  # readonly
    RevisionNumber: str  # readonly
    RootFolder: str

    def InitializeComponent(self) -> None: ...

class FileRevisionDialog(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    AllowOpenAsCheckedout: bool
    RevisionNumber: int  # readonly

    def InitializeComponent(self) -> None: ...

class FolderTree(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...

    SelectedPath: str  # readonly
    ViewModel: FolderTreeViewModel  # readonly

    def Initialize(self) -> Any: ...
    def InitializeComponent(self) -> None: ...
    def SetSelectedFolder(self, pathName: str) -> None: ...

    SelectedItemChanged: System.Windows.RoutedPropertyChangedEventHandler  # Event

class LoginDialog(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    CanLogin: bool  # readonly
    Domain: str
    LogonXml: str  # readonly
    Message: str
    Password: System.Security.SecureString  # readonly
    Server: str
    User: str
    ValidationMode: bool

    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Login() -> Any: ...

    Cancel: System.ComponentModel.CancelEventHandler  # Event
    Logon: System.ComponentModel.CancelEventHandler  # Event

class OpenFileDialog(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    System.Windows.Markup.IStyleConnector,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.FileDialog,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    OpenMode: bool  # readonly

class RelayCommand(System.Windows.Input.ICommand):  # Class
    @overload
    def __init__(self, execute: System.Action) -> None: ...
    @overload
    def __init__(
        self, execute: System.Action, canExecute: System.Predicate
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class SaveFileDialog(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    System.Windows.Markup.IStyleConnector,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.FileDialog,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    OpenMode: bool  # readonly

class Utils:  # Class
    IsECM5OrLater: bool  # static # readonly

    @staticmethod
    def InitComplianceEnvironment() -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.OpenLab.Framework.Common.Utilities

class AppInfo:  # Class
    BuildNumber: str  # static # readonly
    Company: str  # static # readonly
    Copyright: str  # static # readonly
    Description: str  # static # readonly
    FullVersion: str  # static # readonly
    InstalledModules: str  # static # readonly
    Product: str  # static # readonly
    ProductGroup: str  # static
    ProductGroupVersion: str  # static
    ProductShortName: str  # static
    Title: str  # static # readonly
    Version: str  # static # readonly

class EventSubscribers:  # Class
    @staticmethod
    def Get(target: Any, eventName: str) -> List[System.Delegate]: ...

class ParamValidator:  # Class
    @staticmethod
    def CheckLessThan(value_: T, mustBeLessThan: T, parameterName: str) -> T: ...
    @staticmethod
    def CheckEqualOrLessThan(
        value_: T, mustBeEqualOrLessThan: T, parameterName: str
    ) -> T: ...
    @staticmethod
    def CheckGreaterThan(value_: T, mustBeGreaterThan: T, parameterName: str) -> T: ...
    @staticmethod
    def CheckSame(source: T, target: T) -> T: ...
    @staticmethod
    def CheckEqualOrGreaterThan(
        value_: T, mustBeEqualOrGreaterThan: T, parameterName: str
    ) -> T: ...
    @staticmethod
    def CheckNotNull(value_: T, parameterName: str) -> T: ...
    @staticmethod
    def CheckNotNullOrEmpty(value_: str, parameterName: str) -> str: ...
    @staticmethod
    def CheckNotNullAndOfType(value_: Any, parameterName: str) -> T: ...

class StringStream(System.IO.MemoryStream, System.IDisposable):  # Class
    @overload
    def __init__(self, content: str) -> None: ...
    @overload
    def __init__(self, content: str, encoding: System.Text.Encoding) -> None: ...

    String: str  # readonly

    @overload
    @staticmethod
    def ConvertToString(stream: System.IO.Stream) -> str: ...
    @overload
    @staticmethod
    def ConvertToString(
        stream: System.IO.Stream, encoding: System.Text.Encoding
    ) -> str: ...

class TempFileStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, sourceStream: System.IO.Stream) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    Length: int  # readonly
    Position: int

    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def Write(self, buffer: List[int], offset: int, count: int) -> None: ...
    def Flush(self) -> None: ...
    def SetLength(self, value_: int) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    CDBDataSetTableAdapters,
    DeviceType,
    IonizationMode,
    IonPolarity,
    MSScanType,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Compounds

class CDBCompoundsQuery:  # Class
    def __init__(self) -> None: ...

    Agilent_ID: int
    CASNumber: str
    ChemSpider_ID: str
    CompoundID: int
    CompoundName: str
    CreationDateTime: str
    Description: str
    Formula: str
    HMP_ID: str
    IUPACName: str
    KEGG_ID: str
    LMP_ID: str
    LastEditDateTime: str
    METLIN_ID: str
    Mass: float
    RetentionTime: float
    calculateMassDeltas: bool
    calculateRTDeltas: bool
    dynamicColumns: Dict[str, str]
    includeNullRTs: bool
    massTolerance: float
    massUnits: Agilent.MassSpectrometry.DataAnalysis.Compounds.MassUnits
    radicalSearchMode: Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode
    retentionTimeTolerance: float

class CDBCompoundsRecord:  # Class
    def __init__(self) -> None: ...

    Agilent_ID: str
    Anion: bool
    CASNumber: str
    Cation: bool
    ChemSpider_ID: str
    CompoundId: int
    CompoundName: str
    CreationDateTime: System.DateTime
    Description: str
    Formula: str
    HMP_ID: str
    IUPACName: str
    KEGG_ID: str
    LMP_ID: str
    LastEditDateTime: System.DateTime
    METLIN_ID: str
    MOLFile: str
    Mass: float
    RetentionTime: float
    RetentionTimeUpdatedDateTime: System.DateTime

class CDBData(
    System.IDisposable, Agilent.MassSpectrometry.DataAnalysis.Compounds.DisposableBase
):  # Class
    def __init__(self) -> None: ...

    Database: str  # readonly

    @staticmethod
    def ValidLicense() -> bool: ...
    def GetInstrumentTypeEnumFromString(self, instrumentType: str) -> DeviceType: ...
    @staticmethod
    def IsDynamicSchemaSame(databaseFile1: str, databaseFile2: str) -> bool: ...
    def GetYValues(self, compoundID: int, spectrumID: int) -> str: ...
    def GetPolarityEnumFromString(self, polarity: str) -> IonPolarity: ...
    def UpdateDataSet(
        self, dataSet: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet
    ) -> bool: ...
    @overload
    def QueryRecords(
        self, sqlQueryString: str
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBCompoundsRecord]: ...
    @overload
    def QueryRecords(
        self,
        spectraQuery: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBSpectraQuery,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBSpectraRecord]: ...
    def GetCompoundsCount(self) -> int: ...
    def UpdateLibraryInfo(
        self, libInfo: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBLibraryInfo
    ) -> bool: ...
    def SetDatabase(self, dbFilePath: str) -> None: ...
    def QueryLibrary(
        self, cdbQuery: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery
    ) -> System.Data.DataSet: ...
    def GetSpectralPoints(
        self,
        compoundID: int,
        spectrumID: int,
        xValues: List[float],
        yValues: List[float],
    ) -> None: ...
    @overload
    def Initialize(self, databaseFolder: str, id: str) -> bool: ...
    @overload
    def Initialize(self, databaseFolder: str) -> bool: ...
    def GetIonModeEnumFromString(self, ionMode: str) -> IonizationMode: ...
    @overload
    def GetDatabaseInfo(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBLibraryInfo: ...
    @overload
    def GetDatabaseInfo(
        self, dbFile: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBLibraryInfo: ...
    @staticmethod
    def QueryNonResults(dbFileName: str, sqlQuery: str) -> None: ...
    def GetScanTypeEnumFromString(self, scanType: str) -> MSScanType: ...
    @overload
    def IsMaster(self, databaseName: str) -> bool: ...
    @overload
    def IsMaster(self) -> bool: ...
    def AddCompound(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow,
    ) -> bool: ...
    def QueryCompoundRecords(
        self,
        compoundsQuery: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBCompoundsQuery,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBCompoundsRecord]: ...
    @overload
    def IsReadOnly(self, databaseName: str) -> bool: ...
    @overload
    def IsReadOnly(self) -> bool: ...
    def QuerySpectraRecords(
        self, sqlQueryString: str
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBSpectraRecord]: ...
    @overload
    def Query(self, sqlQueryString: str) -> System.Data.DataSet: ...
    @overload
    def Query(
        self,
        compoundsQuery: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBCompoundsQuery,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet: ...
    @overload
    def Query(
        self,
        spectraQuery: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBSpectraQuery,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet: ...
    def AddSpectrum(
        self, row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow
    ) -> bool: ...
    def GetXValues(self, compoundID: int, spectrumID: int) -> str: ...
    def UpdateSpectralDataSet(
        self, dataSet: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet
    ) -> bool: ...

class CDBDataAccess(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.ComponentModel.Component,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, container: System.ComponentModel.IContainer) -> None: ...

class CDBDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    @overload
    def __init__(self, databaseFileName: str) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Compounds: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsDataTable
    )  # readonly
    Library: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Spectra: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraDataTable
    )  # readonly
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def GetDynamicAddedColumns(
        self, table: System.Data.DataTable
    ) -> System.Collections.Generic.List[System.Data.DataColumn]: ...
    def Clone(self) -> System.Data.DataSet: ...
    def GetDynamicRemovedColumns(
        self, table: System.Data.DataTable
    ) -> System.Collections.Generic.List[System.Data.DataColumn]: ...
    @staticmethod
    def GetSqlDBTypeFromType(type: System.Type) -> System.Data.SqlDbType: ...

    # Nested Types

    class CompoundsDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ],
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        Agilent_IDColumn: System.Data.DataColumn  # readonly
        AnionColumn: System.Data.DataColumn  # readonly
        BestFitColumn: System.Data.DataColumn  # readonly
        CASNumberColumn: System.Data.DataColumn  # readonly
        CationColumn: System.Data.DataColumn  # readonly
        ChemSpider_IDColumn: System.Data.DataColumn  # readonly
        CompoundIDColumn: System.Data.DataColumn  # readonly
        CompoundNameColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        CreationDateTimeColumn: System.Data.DataColumn  # readonly
        DeltaMassColumn: System.Data.DataColumn  # readonly
        DeltaRetentionTimeColumn: System.Data.DataColumn  # readonly
        DescriptionColumn: System.Data.DataColumn  # readonly
        FormulaColumn: System.Data.DataColumn  # readonly
        HMP_IDColumn: System.Data.DataColumn  # readonly
        IUPACNameColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ): ...
        KEGG_IDColumn: System.Data.DataColumn  # readonly
        LMP_IDColumn: System.Data.DataColumn  # readonly
        LastEditDateTimeColumn: System.Data.DataColumn  # readonly
        METLIN_IDColumn: System.Data.DataColumn  # readonly
        MassColumn: System.Data.DataColumn  # readonly
        MassSubmittedColumn: System.Data.DataColumn  # readonly
        MolFileColumn: System.Data.DataColumn  # readonly
        NumSpectraColumn: System.Data.DataColumn  # readonly
        RTUpdatedTimeColumn: System.Data.DataColumn  # readonly
        RetentionIndexColumn: System.Data.DataColumn  # readonly
        RetentionTimeColumn: System.Data.DataColumn  # readonly
        RetentionTimeSubmittedColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def RemoveCompoundsRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow,
        ) -> None: ...
        def Clone(self) -> System.Data.DataTable: ...
        def NewCompoundsRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ): ...
        def FindByCompoundID(
            self, CompoundID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ): ...
        @overload
        def AddCompoundsRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow,
        ) -> None: ...
        @overload
        def AddCompoundsRow(
            self,
            CompoundName: str,
            Description: str,
            Formula: str,
            Mass: float,
            RetentionTime: float,
            Cation: bool,
            Anion: bool,
            CASNumber: str,
            HMP_ID: str,
            KEGG_ID: str,
            LMP_ID: str,
            METLIN_ID: str,
            ChemSpider_ID: str,
            Agilent_ID: int,
            MolFile: str,
            IUPACName: str,
            CreationDateTime: System.DateTime,
            LastEditDateTime: System.DateTime,
            RTUpdatedTime: System.DateTime,
            MassSubmitted: float,
            DeltaMass: float,
            RetentionTimeSubmitted: float,
            DeltaRetentionTime: float,
            BestFit: bool,
            NumSpectra: int,
            RetentionIndex: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        ): ...

        CompoundsRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEventHandler
        )  # Event
        CompoundsRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEventHandler
        )  # Event
        CompoundsRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEventHandler
        )  # Event
        CompoundsRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEventHandler
        )  # Event

    class CompoundsRow(System.Data.DataRow):  # Class
        Agilent_ID: int
        Anion: bool
        BestFit: bool
        CASNumber: str
        Cation: bool
        ChemSpider_ID: str
        CompoundID: int
        CompoundName: str
        CreationDateTime: System.DateTime
        DeltaMass: float
        DeltaRetentionTime: float
        Description: str
        Formula: str
        HMP_ID: str
        IUPACName: str
        KEGG_ID: str
        LMP_ID: str
        LastEditDateTime: System.DateTime
        METLIN_ID: str
        Mass: float
        MassSubmitted: float
        MolFile: str
        NumSpectra: int
        RTUpdatedTime: System.DateTime
        RetentionIndex: float
        RetentionTime: float
        RetentionTimeSubmitted: float

        def IsIUPACNameNull(self) -> bool: ...
        def IsMassSubmittedNull(self) -> bool: ...
        def SetLMP_IDNull(self) -> None: ...
        def IsRetentionIndexNull(self) -> bool: ...
        def SetNumSpectraNull(self) -> None: ...
        def IsCationNull(self) -> bool: ...
        def IsAgilent_IDNull(self) -> bool: ...
        def IsAnionNull(self) -> bool: ...
        def IsLastEditDateTimeNull(self) -> bool: ...
        def SetAgilent_IDNull(self) -> None: ...
        def SetCationNull(self) -> None: ...
        def SetDeltaRetentionTimeNull(self) -> None: ...
        def IsRTUpdatedTimeNull(self) -> bool: ...
        def SetHMP_IDNull(self) -> None: ...
        def SetLastEditDateTimeNull(self) -> None: ...
        def SetMETLIN_IDNull(self) -> None: ...
        def SetMassSubmittedNull(self) -> None: ...
        def SetDeltaMassNull(self) -> None: ...
        def IsCreationDateTimeNull(self) -> bool: ...
        def SetFormulaNull(self) -> None: ...
        def SetBestFitNull(self) -> None: ...
        def IsRetentionTimeNull(self) -> bool: ...
        def IsFormulaNull(self) -> bool: ...
        def IsLMP_IDNull(self) -> bool: ...
        def SetMolFileNull(self) -> None: ...
        def IsDescriptionNull(self) -> bool: ...
        def SetIUPACNameNull(self) -> None: ...
        def SetRetentionTimeSubmittedNull(self) -> None: ...
        def SetRTUpdatedTimeNull(self) -> None: ...
        def SetRetentionIndexNull(self) -> None: ...
        def IsNumSpectraNull(self) -> bool: ...
        def IsHMP_IDNull(self) -> bool: ...
        def IsMETLIN_IDNull(self) -> bool: ...
        def IsMolFileNull(self) -> bool: ...
        def IsDeltaRetentionTimeNull(self) -> bool: ...
        def SetRetentionTimeNull(self) -> None: ...
        def SetDescriptionNull(self) -> None: ...
        def IsCompoundNameNull(self) -> bool: ...
        def IsDeltaMassNull(self) -> bool: ...
        def IsCASNumberNull(self) -> bool: ...
        def SetKEGG_IDNull(self) -> None: ...
        def SetAnionNull(self) -> None: ...
        def SetCompoundNameNull(self) -> None: ...
        def SetChemSpider_IDNull(self) -> None: ...
        def IsKEGG_IDNull(self) -> bool: ...
        def SetCASNumberNull(self) -> None: ...
        def SetCreationDateTimeNull(self) -> None: ...
        def IsChemSpider_IDNull(self) -> bool: ...
        def IsRetentionTimeSubmittedNull(self) -> bool: ...
        def IsBestFitNull(self) -> bool: ...

    class CompoundsRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRow
        )  # readonly

    class CompoundsRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.CompoundsRowChangeEvent,
        ) -> None: ...

    class LibraryDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        Iterable[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow],
        System.ComponentModel.IComponent,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow
        ],
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        CreationDateTimeColumn: System.Data.DataColumn  # readonly
        DescriptionColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow: ...
        LastEditDateTimeColumn: System.Data.DataColumn  # readonly
        LibraryIDColumn: System.Data.DataColumn  # readonly
        LibraryNameColumn: System.Data.DataColumn  # readonly
        LibrarySourceColumn: System.Data.DataColumn  # readonly
        LibrarySourceVersionColumn: System.Data.DataColumn  # readonly
        LibraryTypeColumn: System.Data.DataColumn  # readonly
        LibraryVersionMajorColumn: System.Data.DataColumn  # readonly
        LibraryVersionMinorColumn: System.Data.DataColumn  # readonly
        MasterColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewLibraryRow(
            self,
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow: ...
        def FindByLibraryID(
            self, LibraryID: int
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow: ...
        @overload
        def AddLibraryRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow,
        ) -> None: ...
        @overload
        def AddLibraryRow(
            self,
            LibraryName: str,
            LibraryType: str,
            Description: str,
            LibrarySource: str,
            LibrarySourceVersion: str,
            LibraryVersionMajor: int,
            LibraryVersionMinor: int,
            Master: bool,
            CreationDateTime: System.DateTime,
            LastEditDateTime: System.DateTime,
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow: ...
        def Clone(self) -> System.Data.DataTable: ...
        def RemoveLibraryRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow,
        ) -> None: ...

        LibraryRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEventHandler
        )  # Event
        LibraryRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEventHandler
        )  # Event
        LibraryRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEventHandler
        )  # Event
        LibraryRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEventHandler
        )  # Event

    class LibraryRow(System.Data.DataRow):  # Class
        CreationDateTime: System.DateTime
        Description: str
        LastEditDateTime: System.DateTime
        LibraryID: int
        LibraryName: str
        LibrarySource: str
        LibrarySourceVersion: str
        LibraryType: str
        LibraryVersionMajor: int
        LibraryVersionMinor: int
        Master: bool

        def SetCreationDateTimeNull(self) -> None: ...
        def SetDescriptionNull(self) -> None: ...
        def SetLibraryVersionMinorNull(self) -> None: ...
        def IsLibraryNameNull(self) -> bool: ...
        def SetLibraryVersionMajorNull(self) -> None: ...
        def IsLibraryTypeNull(self) -> bool: ...
        def SetMasterNull(self) -> None: ...
        def IsLibraryVersionMajorNull(self) -> bool: ...
        def SetLibrarySourceNull(self) -> None: ...
        def SetLibrarySourceVersionNull(self) -> None: ...
        def SetLastEditDateTimeNull(self) -> None: ...
        def IsLibrarySourceVersionNull(self) -> bool: ...
        def IsLibraryVersionMinorNull(self) -> bool: ...
        def IsCreationDateTimeNull(self) -> bool: ...
        def SetLibraryTypeNull(self) -> None: ...
        def IsDescriptionNull(self) -> bool: ...
        def IsLastEditDateTimeNull(self) -> bool: ...
        def IsLibrarySourceNull(self) -> bool: ...
        def SetLibraryNameNull(self) -> None: ...
        def IsMasterNull(self) -> bool: ...

    class LibraryRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRow
        )  # readonly

    class LibraryRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.LibraryRowChangeEvent,
        ) -> None: ...

    class SpectraDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow
        ],
        Iterable[Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        AbundanceValuesColumn: System.Data.DataColumn  # readonly
        CollisionEnergyColumn: System.Data.DataColumn  # readonly
        CompoundIDColumn: System.Data.DataColumn  # readonly
        CompoundNameColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        CreationDateTimeColumn: System.Data.DataColumn  # readonly
        FragmentorColumn: System.Data.DataColumn  # readonly
        HighestMzColumn: System.Data.DataColumn  # readonly
        InstrumentTypeColumn: System.Data.DataColumn  # readonly
        IonModeColumn: System.Data.DataColumn  # readonly
        IonPolarityColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow: ...
        LastEditDateTimeColumn: System.Data.DataColumn  # readonly
        LowestMzColumn: System.Data.DataColumn  # readonly
        MSLevelColumn: System.Data.DataColumn  # readonly
        MzValuesColumn: System.Data.DataColumn  # readonly
        ScanTypeColumn: System.Data.DataColumn  # readonly
        SelectedMzColumn: System.Data.DataColumn  # readonly
        SpeciesColumn: System.Data.DataColumn  # readonly
        SpectrumIDColumn: System.Data.DataColumn  # readonly

        def NewSpectraRow(
            self,
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        @overload
        def AddSpectraRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow,
        ) -> None: ...
        @overload
        def AddSpectraRow(
            self,
            CompoundID: int,
            CompoundName: str,
            MzValues: str,
            AbundanceValues: str,
            SelectedMz: float,
            LowestMz: float,
            HighestMz: float,
            CollisionEnergy: float,
            Fragmentor: float,
            InstrumentType: str,
            IonPolarity: str,
            IonMode: str,
            MSLevel: int,
            ScanType: str,
            CreationDateTime: System.DateTime,
            LastEditDateTime: System.DateTime,
            Species: str,
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow: ...
        def Clone(self) -> System.Data.DataTable: ...
        def FindByCompoundIDSpectrumID(
            self, CompoundID: int, SpectrumID: int
        ) -> Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow: ...
        def RemoveSpectraRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow,
        ) -> None: ...

        SpectraRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEventHandler
        )  # Event
        SpectraRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEventHandler
        )  # Event
        SpectraRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEventHandler
        )  # Event
        SpectraRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEventHandler
        )  # Event

    class SpectraRow(System.Data.DataRow):  # Class
        AbundanceValues: str
        CollisionEnergy: float
        CompoundID: int
        CompoundName: str
        CreationDateTime: System.DateTime
        Fragmentor: float
        HighestMz: float
        InstrumentType: str
        IonMode: str
        IonPolarity: str
        LastEditDateTime: System.DateTime
        LowestMz: float
        MSLevel: int
        MzValues: str
        ScanType: str
        SelectedMz: float
        Species: str
        SpectrumID: int

        def SetLowestMzNull(self) -> None: ...
        def IsAbundanceValuesNull(self) -> bool: ...
        def SetSpeciesNull(self) -> None: ...
        def IsLastEditDateTimeNull(self) -> bool: ...
        def IsScanTypeNull(self) -> bool: ...
        def IsIonModeNull(self) -> bool: ...
        def SetLastEditDateTimeNull(self) -> None: ...
        def IsCreationDateTimeNull(self) -> bool: ...
        def SetAbundanceValuesNull(self) -> None: ...
        def SetIonPolarityNull(self) -> None: ...
        def IsMzValuesNull(self) -> bool: ...
        def IsLowestMzNull(self) -> bool: ...
        def IsIonPolarityNull(self) -> bool: ...
        def IsCollisionEnergyNull(self) -> bool: ...
        def IsFragmentorNull(self) -> bool: ...
        def SetHighestMzNull(self) -> None: ...
        def IsMSLevelNull(self) -> bool: ...
        def IsInstrumentTypeNull(self) -> bool: ...
        def IsSelectedMzNull(self) -> bool: ...
        def IsCompoundNameNull(self) -> bool: ...
        def SetSelectedMzNull(self) -> None: ...
        def SetInstrumentTypeNull(self) -> None: ...
        def SetScanTypeNull(self) -> None: ...
        def SetMzValuesNull(self) -> None: ...
        def IsHighestMzNull(self) -> bool: ...
        def SetCollisionEnergyNull(self) -> None: ...
        def SetMSLevelNull(self) -> None: ...
        def SetIonModeNull(self) -> None: ...
        def SetCompoundNameNull(self) -> None: ...
        def SetFragmentorNull(self) -> None: ...
        def SetCreationDateTimeNull(self) -> None: ...
        def IsSpeciesNull(self) -> bool: ...

    class SpectraRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRow
        )  # readonly

    class SpectraRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSet.SpectraRowChangeEvent,
        ) -> None: ...

class CDBLibraryInfo:  # Class
    def __init__(self) -> None: ...

    CreationDateTime: System.DateTime
    Description: str
    LastEditDateTime: System.DateTime
    LibraryID: int
    LibraryName: str
    LibrarySource: str
    LibrarySourceVersion: str
    LibraryType: str
    LibraryVersionMajor: int
    LibraryVersionMinor: int
    Master: bool

class CDBQuery:  # Class
    def __init__(self) -> None: ...

    m_queryParts: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBQueryPart
    ]

    def AddCondition(
        self,
        field: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField,
        options: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare,
        value_: Any,
    ) -> None: ...

    # Nested Types

    class CDBCompare(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Contains: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare
        ) = ...  # static # readonly
        Equals: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare = (
            ...
        )  # static # readonly
        GreaterThan: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare
        ) = ...  # static # readonly
        LessThan: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare
        ) = ...  # static # readonly
        Not: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare = (
            ...
        )  # static # readonly

    class CDBField(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        AbundanceValues: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        Agilent_ID: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CASNumber: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        ChemSpider_ID: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CollisionEnergy: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CompoundID: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CompoundName: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CompoundSpecID: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        CreationDateTime: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        Description: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        Formula: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        Fragmentor: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        HMP_ID: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        HighestMz: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        IUPACName: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        IncludeCompounds: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        IncludeSpectra: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        InstrumentType: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        IonMode: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        IonPolarity: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        KEGG_ID: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        LMP_ID: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        LastEditDateTime: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        LowestMz: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        METLIN_ID: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        Mass: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        MolFile: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        MsLevel: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        MzValues: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        RadicalSearchMode: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        RetentionTime: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        ScanType: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        SelectedMz: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        SpecCreationDateTime: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        SpecLastEditDateTime: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly
        Species: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField = (
            ...
        )  # static # readonly
        SpectrumID: (
            Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        ) = ...  # static # readonly

    class CDBQueryPart:  # Class
        def __init__(self) -> None: ...

        condition: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBCompare
        field: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBQuery.CDBField
        value: Any

class CDBSpectraQuery:  # Class
    def __init__(self) -> None: ...

    CollisionEnergy: float
    CompoundID: int
    CreationDateTime: str
    Fragmentor: float
    InstrumentType: DeviceType
    IonMode: IonizationMode
    IonPolarity: IonPolarity
    LastEditDateTime: str
    MSLevel: int
    ScanType: MSScanType
    SelectedMz: float
    SpectrumID: int
    ceTolerance: float
    dynamicColumns: Dict[str, str]
    massTolerance: float
    massUnits: Agilent.MassSpectrometry.DataAnalysis.Compounds.MassUnits

class CDBSpectraRecord:  # Class
    def __init__(self) -> None: ...

    AbundanceValues: str
    CollisionEnergy: float
    CompoundId: int
    CreationDateTime: System.DateTime
    Fragmentor: float
    HighestMz: float
    InstrumentType: str
    IonMode: str
    IonPolarity: str
    LastEditDateTime: System.DateTime
    LowestMz: float
    MSLevel: int
    MzValues: str
    ScanType: str
    SelectedMz: float
    Species: str
    SpectrumId: int

class DisposableBase(System.IDisposable):  # Class
    def Dispose(self) -> None: ...

class MassUnits(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    mDa: Agilent.MassSpectrometry.DataAnalysis.Compounds.MassUnits = (
        ...
    )  # static # readonly
    ppm: Agilent.MassSpectrometry.DataAnalysis.Compounds.MassUnits = (
        ...
    )  # static # readonly

class RadicalSearchMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    IncludeAnions: Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode = (
        ...
    )  # static # readonly
    IncludeCations: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode
    ) = ...  # static # readonly
    IncludeEverything: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode
    ) = ...  # static # readonly
    IncludeNeutrals: (
        Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode
    ) = ...  # static # readonly
    NotSpecified: Agilent.MassSpectrometry.DataAnalysis.Compounds.RadicalSearchMode = (
        ...
    )  # static # readonly
